********************************
Custom Horizon pages for Savanna
********************************

Some pages has been implemented and there are some screenshots of it.
Screencast and sources of customized Horizon will be published at an early date.


1. Base page with Hadoop clusters list (empty cluster list).

.. image:: ../images/horizon/01-savanna-empty.png
    :width: 800 px
    :scale: 99 %
    :align: left

2. Node template details page

.. image:: ../images/horizon/02-savanna-tmpl.png
    :width: 800 px
    :scale: 99 %
    :align: left

3. Hadoop cluster creation wizard

.. image:: ../images/horizon/03-savanna-create.png
    :width: 800 px
    :scale: 99 %
    :align: left

4. Hadoop clusters page with new cluster in 'Starting' state

.. image:: ../images/horizon/04-savanna-starting.png
    :width: 800 px
    :scale: 99 %
    :align: left

5. After some time, cluster is active

.. image:: ../images/horizon/05-savanna-active.png
    :width: 800 px
    :scale: 99 %
    :align: left

6. Hadoop cluster details page

.. image:: ../images/horizon/06-savanna-details.png
    :width: 800 px
    :scale: 99 %
    :align: left
